# villaAuth code
> allow authentication with cognito to generate aws credentials


## Install

`pip install villaAuth`

## How to use

Fill me in please! Don't forget code examples:

```
1+1
```




    2


